var _runtime__shader__generation =
[
    [ "RTSS: Run Time Shader System", "rtss.html", [
      [ "Core features of the system", "rtss.html#core-feats", null ],
      [ "System overview", "rtss.html#rtss_overview", [
        [ "Customizing the RTSS using Material Scripts", "rtss.html#rtss_custom_mat", null ],
        [ "Customising the RTSS using the API", "rtss.html#rtss_custom_api", null ]
      ] ],
      [ "The RTSS in Depth", "rtss.html#rtss_indepth", [
        [ "Main components", "rtss.html#rtss__components", null ],
        [ "Creating shader based technique", "rtss.html#rtssTech", null ],
        [ "Runtime shader generation", "rtss.html#rtssGenerate", null ],
        [ "Creating custom shader extensions", "rtss.html#creating-extensions", null ],
        [ "Tips for debugging shaders", "rtss.html#debugging", null ]
      ] ]
    ] ],
    [ "HLMS: High Level Material System", "hlms.html", [
      [ "The three components", "hlms.html#components", null ],
      [ "Material parameters are stored in “Blocks”", "hlms.html#data", [
        [ "Datablocks", "hlms.html#toc52", null ]
      ] ],
      [ "Hlms templates", "hlms.html#toc69", [
        [ "The Hlms preprocessor", "hlms.html#preproc", null ],
        [ "Preprocessor syntax", "hlms.html#syntax", null ]
      ] ],
      [ "Creation of shaders", "hlms.html#shaders", null ],
      [ "C++ interaction with shader templates", "hlms.html#cpp", null ],
      [ "Customization", "hlms.html#customization", null ]
    ] ]
];